"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.masking_job_sets_api import MaskingJobSetsApi  # noqa: E501


class TestMaskingJobSetsApi(unittest.TestCase):
    """MaskingJobSetsApi unit test stubs"""

    def setUp(self):
        self.api = MaskingJobSetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_masking_job_set_tag(self):
        """Test case for create_masking_job_set_tag

        Create tags for a Masking Job Set.  # noqa: E501
        """
        pass

    def test_delete_masking_job_set_tag(self):
        """Test case for delete_masking_job_set_tag

        Delete tags for a Masking Job Set.  # noqa: E501
        """
        pass

    def test_get_masking_job_set_by_id(self):
        """Test case for get_masking_job_set_by_id

        Retrieve a MaskingJobSet by ID.  # noqa: E501
        """
        pass

    def test_get_masking_job_set_connectors(self):
        """Test case for get_masking_job_set_connectors

        Get connectors for a Masking Job Set for a specific engine.  # noqa: E501
        """
        pass

    def test_get_masking_job_set_tag(self):
        """Test case for get_masking_job_set_tag

        Get tags for a Masking Job Set.  # noqa: E501
        """
        pass

    def test_get_masking_job_sets(self):
        """Test case for get_masking_job_sets

        Retrieve the list of masking job sets.  # noqa: E501
        """
        pass

    def test_search_masking_job_sets(self):
        """Test case for search_masking_job_sets

        Search masking job sets.  # noqa: E501
        """
        pass

    def test_update_masking_job_set_by_id(self):
        """Test case for update_masking_job_set_by_id

        Update values of a MaskingJobSet.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
