"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.authorization_api import AuthorizationApi  # noqa: E501


class TestAuthorizationApi(unittest.TestCase):
    """AuthorizationApi unit test stubs"""

    def setUp(self):
        self.api = AuthorizationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_access_group_account_ids(self):
        """Test case for add_access_group_account_ids

        Add account ids to an Access group  # noqa: E501
        """
        pass

    def test_add_access_group_account_tags(self):
        """Test case for add_access_group_account_tags

        Add account tags to an Access group  # noqa: E501
        """
        pass

    def test_add_access_group_policies(self):
        """Test case for add_access_group_policies

        Add policies to an Access group  # noqa: E501
        """
        pass

    def test_create_access_group(self):
        """Test case for create_access_group

        Create a new access group.  # noqa: E501
        """
        pass

    def test_delete_access_group(self):
        """Test case for delete_access_group

        Delete an Access group.  # noqa: E501
        """
        pass

    def test_get_access_group_by_id(self):
        """Test case for get_access_group_by_id

        Returns an Access group by ID.  # noqa: E501
        """
        pass

    def test_get_access_groups(self):
        """Test case for get_access_groups

        List all access groups.  # noqa: E501
        """
        pass

    def test_get_role_by_id(self):
        """Test case for get_role_by_id

        Returns role by ID.  # noqa: E501
        """
        pass

    def test_get_roles(self):
        """Test case for get_roles

        List all roles  # noqa: E501
        """
        pass

    def test_remove_access_group_account_id(self):
        """Test case for remove_access_group_account_id

        Remove the account from the access group.  # noqa: E501
        """
        pass

    def test_remove_access_group_account_tags(self):
        """Test case for remove_access_group_account_tags

        Remove account tags from an access group.  # noqa: E501
        """
        pass

    def test_remove_access_group_policy(self):
        """Test case for remove_access_group_policy

        Remove the policy from the Access group.  # noqa: E501
        """
        pass

    def test_update_access_group(self):
        """Test case for update_access_group

        Update an Access group.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
